@@ -3,10 +3,21 @@ use 5.008005;
 use strict;
 use warnings;
 
-our $VERSION = "0.12";
+our $VERSION = "0.13";
 
+use parent 'Exporter';
+use SQL::QueryMaker;
 use DBIx::Otogiri;
 
+our @EXPORT = map {"sql_$_"} qw/
+    eq like lt gt le ge
+    is_null is_not_null
+    between not_between
+    in not_in
+    and or not
+    op raw
+/;
+
 sub new {
     my ($class, %opts) = @_;
     DBIx::Otogiri->new(%opts);
@@ -33,11 +44,21 @@ Otogiri - A lightweight medicine for using database
 
     print 'Title: '. $row->{title}. "\n";
     
+    my @rows = $db->select(book => sql_ge(price => 500));
+    
+    ### or non-strict mode
     my @rows = $db->select(book => {price => {'>=' => 500}});
+
     for my $r (@rows) {
         printf "Title: %s \nPrice: %s yen\n", $r->{title}, $r->{price};
     }
     
+    # or using iterator
+    my $iter = $db->select(book => {price => {'>=' => 500}});
+    while (my $row = $iter->next) {
+        printf "Title: %s \nPrice: %s yen\n", $row->{title}, $row->{price};
+    }
+    
     $db->update(book => [author => 'oreore'], {author => 'me'});
     
     $db->delete(book => {author => 'me'});
@@ -66,7 +87,11 @@ Please see ATTRIBUTES section of L<DBIx::Otogiri> documentation.
 
 Instantiate and connect to db. Then, it returns L<DBIx::Otogiri> object.
 
-Please see ATTRIBUTE section.
+=head1 EXPORT FUNCTIONS
+
+Otogiri exports each SQL::QueryMaker::sql_* functions. (ex. sql_ge(), sql_like() and more...)
+
+For more information, please see FUNCTIONS section of L<SQL::QueryMaker>'s documentation.
 
 =head1 INFORMATION ABOUT INCOMPATIBILITY
 
@@ -99,5 +124,7 @@ L<DBIx::Sunny>
 
 L<SQL::Maker>
 
+L<SQL::QueryMaker>
+
 =cut
 
